#!/bin/bash

export compose_version="1.24.1";
export cilium_version="1.4.1";
export cilium_options="--kvstore consul --kvstore-opt consul.address=127.0.0.1:8500 --tunnel disabled"; #-t vxlan 
export temp_dir="$(mktemp -d)"
export base_dir="$(readlink -f "$(dirname $0)/..")"

function hash_if_existing {
	sha1sum "${1}" | cut -d' ' -f1
}

function copy_if_necessary {
	target="${base_dir}/${1}"
	temporary="${temp_dir}/${1}"

	if [[ ${2} -eq 0 ]]; then
		echo -n " OK";

		if [[ -f "${target}" ]]; then
			existing_hash="$(hash_if_existing "${target}")"
			temporary_hash="$(hash_if_existing "${temporary}")"

			if [[ "${existing_hash}" == "${temporary_hash}" ]]; then
				copy_file=0;
			else
				copy_file=1;
			fi;
		else
			copy_file=1;
		fi;

		if [[ ${copy_file} -eq 1 ]]; then
			echo " - changed!"
			cp --preserve=all "${temporary}" "${target}"

			return $?;
		else
			echo " - no update"
			return 0;
		fi;
	else
		echo " Error!"
		return 1;
	fi;
}

function template_if_necessary {
	temporary="${temp_dir}/${1}"
	template="${base_dir}/update-templates/${1}.template"

	echo -n "Templating \"${1}.template\"..."
	sed_script="${2}"

	sed "${sed_script}" "${template}" > "${temporary}"

	copy_if_necessary "${1}" "$?"
	return $?
}

function update_if_necessary {
	temporary="${temp_dir}/${1}"
	url="${2}"
	options="${3}"

	echo -n "Fetching \"${url}\"..."
	wget -q ${options} -O "${temporary}" "${url}"

	copy_if_necessary "${1}" "$?"
	return $?
}

update_if_necessary 'docker-ubuntu.asc' "https://download.docker.com/linux/ubuntu/gpg"
update_if_necessary 'docker-compose' "https://github.com/docker/compose/releases/download/${compose_version}/docker-compose-Linux-x86_64"
update_if_necessary 'cilium' "https://releases.cilium.io/v${cilium_version}/cilium-x86_64" --no-check-certificate
update_if_necessary 'cilium-docker-compose.yml' "https://raw.githubusercontent.com/cilium/cilium/master/examples/getting-started/docker-compose.yml"
template_if_necessary 'cilium-helper.sh' 's/{{ cilium_tag }}/'"${cilium_version}"'/g; s/{{ cilium_options }}/'"${cilium_options}"'/g;'

rm -r "${temp_dir}"
